%% Visualisation and plotting
%
%% Opening a figure
h = figure
%
%% Plotting three sine waves with different frequencies
x = 0:.2:20;
y = sin(x)./sqrt(x+1);
y(2,:) = sin(x/2)./sqrt(x+1);
y(3,:) = sin(x/3)./sqrt(x+1);
plot(x,y)
%
%% Displaying multiple plots per figure
%
t = 0:pi/20:2*pi; 
[x,y] = meshgrid(t); 
subplot(2,2,1); plot(sin(t),cos(t)); axis equal;
subplot(2,2,2); z = sin(x)+cos(y); plot(t,z); axis([0 2*pi -2 2]);
subplot(2,2,3); z = sin(x).*cos(y); plot(t,z); axis([0 2*pi -1 1]);
subplot(2,2,4); z = (sin(x).^2)-(cos(y).^2); plot(t,z); axis([0 2*pi -1 1]);
%
%% Specifying the target axes 
%
h = get(gcf,'Children');
subplot(h(1)); title('Most recently created axes');
subplot(gca); title('Current active axes');
%
%% Creating line plots
clf;
t = 0:pi/100:2*pi; 
y = sin(t); 
plot(t,y);
grid on % Turn on grid lines for this plot
%
%% Plotting x,y pairs
%
y = sin(t);
y2 = sin(t-0.25);
y3 = sin(t-0.5); 
plot(t,y,t,y2,t,y3)
%
%% Specifying line styles
%
plot(t,y,'-',t,y2,'--',t,y3,':')
%
%% Specifying color and size of lines
%
x = -pi:pi/10:pi; 
y = tan(sin(x)) - sin(tan(x)); 
plot(x,y,'--rs','LineWidth',2,...
    'MarkerEdgeColor','k',... 
    'MarkerFaceColor','g',...
    'MarkerSize',10);
%
%% Adding plots to an existing graph
%
clf
semilogx(1:100,'+') 
hold all % hold plot and cycle line colors 
%%
plot(1:3:300,1:100,'--') 
hold off 
grid on % Turn on grid lines for this plot 
%
%% Line plots of matrix data
%
Z = peaks
plot(Z)
%
%% Plotting with two y axes
%
clf
t = 0:pi/20:2*pi;
y = exp(sin(t));
plotyy(t,y,t,y,'plot','stem')
%
%% Combining linear and logarithmic axes
%
clf
t = 0:900; A = 1000; a = 0.005; b = 0.005; 
z1 = A*exp(-a*t); 
z2 = sin(b*t); 
[haxes,hline1,hline2] = plotyy(t,z1,t,z2,'semilogy','plot'); 
axes(haxes(1)) 
ylabel('Semilog Plot')
axes(haxes(2)) 
ylabel('Linear Plot')
set(hline2,'LineStyle','--')
%
%% Setting axis parameters
%
clf
plot( 1:0.1:5, 1:0.1:5, 'r--' );
%
% Get current axis limits
axis
%
%% semiautomatic limits
%
axis([-Inf 5 2 2.5]);
axis
%
%% Axis tick marks
%
set(gca,'YTick',[2 2.1 2.2 2.3 2.4 2.5]);
%
%% Specifying Ticks and Tick Labels
%
clf
x = -pi:.1:pi;
y = sin(x);
plot(x,y);
set(gca,'XTick',-pi:pi/2:pi);
set(gca,'XTickLabel',{'-pi','-pi/2','0','pi/2','pi'})
xlabel('-\pi \leq \Theta \leq \pi');
ylabel('sin(\Theta)');
title('Plot of sin(\Theta)');
text(-pi/4,sin(-pi/4),'\leftarrow sin(-\pi\div4)',...
    'HorizontalAlignment','left');
%
%% Setting aspect ratio
%
close all
h = figure;
t = 0:pi/20:2*pi;
subplot( 2,2,1 ); plot(sin(t),2*cos(t)); grid on; xlabel( 'Figure aspect ratio' )
subplot( 2,2,2 ); plot(sin(t),2*cos(t)); grid on; axis square; xlabel( 'axis square' )
subplot( 2,2,3 ); plot(sin(t),2*cos(t)); grid on; axis equal; xlabel( 'axis equal' )
subplot( 2,2,4 ); plot(sin(t),2*cos(t)); grid on; axis equal tight; xlabel( 'axis equal tight' )
%
%% Printing and exporting
print( h, '-r600', '-dpng', 'axisAspect.png' );




